@@ -33,7 +33,7 @@ var searchData=
   ['deselectaccessiblechild',['deselectAccessibleChild',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleSelection.html#a550c752d660e922475f4bbdb9a1e2d3f',1,'com::sun::star::accessibility::XAccessibleSelection']]],
   ['deselectallrows',['deselectAllRows',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridRowSelection.html#a58319da156691ecc5ebceac5cbb3f839',1,'com::sun::star::awt::grid::XGridRowSelection']]],
   ['deselectrow',['deselectRow',['../interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridRowSelection.html#a79e70c5340be3a516c47ff51a59ce02c',1,'com::sun::star::awt::grid::XGridRowSelection']]],
-  ['destroy',['destroy',['../interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a3a80b6032f86a56bec74609034b3246f',1,'com::sun::star::registry::XSimpleRegistry::destroy()'],['../interfacecom_1_1sun_1_1star_1_1mozilla_1_1XPluginInstance.html#a3a80b6032f86a56bec74609034b3246f',1,'com::sun::star::mozilla::XPluginInstance::destroy()']]],
+  ['destroy',['destroy',['../interfacecom_1_1sun_1_1star_1_1registry_1_1XSimpleRegistry.html#a3a80b6032f86a56bec74609034b3246f',1,'com::sun::star::registry::XSimpleRegistry']]],
   ['destroybuffers',['destroyBuffers',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XBufferController.html#aac3d764e57ec1064b7b82ec8322404e3',1,'com::sun::star::rendering::XBufferController']]],
   ['destroyelement',['destroyElement',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XLayoutManager.html#a0b443e2c14b98bdd4392593094845fd7',1,'com::sun::star::frame::XLayoutManager']]],
   ['destroygraph',['destroyGraph',['../interfacecom_1_1sun_1_1star_1_1rdf_1_1XRepository.html#a5cac8eee77b972e38e42896253a68e8f',1,'com::sun::star::rdf::XRepository']]],
@@ -68,7 +68,6 @@ var searchData=
   ['dispatchwithreturnvalue',['dispatchWithReturnValue',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XSynchronousDispatch.html#ac263adb47abe152c597bf1f7eba99cd1',1,'com::sun::star::frame::XSynchronousDispatch']]],
   ['displaypropertypage',['displayPropertyPage',['../interfacecom_1_1sun_1_1star_1_1smarttags_1_1XSmartTagRecognizer.html#acdfafa03525116feb9963f502e7b9c1b',1,'com::sun::star::smarttags::XSmartTagRecognizer']]],
   ['displayslide',['displaySlide',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#af45c672b11592a3f0fb4539946cc43f6',1,'com::sun::star::presentation::XSlideShow']]],
-  ['displaystatustext',['displayStatusText',['../interfacecom_1_1sun_1_1star_1_1plugin_1_1XPluginContext.html#afa9a8e4e8f77c3c2e500364aa162452d',1,'com::sun::star::plugin::XPluginContext']]],
   ['dispose',['dispose',['../interfacecom_1_1sun_1_1star_1_1lang_1_1XComponent.html#ab953e90edb69534eb052f9064f6b40e9',1,'com::sun::star::lang::XComponent::dispose()'],['../interfacecom_1_1sun_1_1star_1_1uno_1_1XReference.html#ab953e90edb69534eb052f9064f6b40e9',1,'com::sun::star::uno::XReference::dispose()']]],
   ['disposing',['disposing',['../interfacecom_1_1sun_1_1star_1_1lang_1_1XEventListener.html#aae6e796f0b3b6a2dba2c1a6bda1a10a1',1,'com::sun::star::lang::XEventListener']]],
   ['doaccessibleaction',['doAccessibleAction',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleAction.html#aa0f4dced146836460d9e6ba2a19349a7',1,'com::sun::star::accessibility::XAccessibleAction']]],
